langtools/src/share/classes/com/sun/tools/doclets/internal/toolkit/util/links/LinkInfo.java
changeset 1787 1aa079321cd2
parent 10 06bc494ca11e
child 5520 86e4b9a9da40
--- a/langtools/src/share/classes/com/sun/tools/doclets/internal/toolkit/util/links/LinkInfo.java	Fri Dec 05 21:59:59 2008 -0800
+++ b/langtools/src/share/classes/com/sun/tools/doclets/internal/toolkit/util/links/LinkInfo.java	Thu Jan 08 16:26:59 2009 -0800
@@ -69,9 +69,9 @@
     public String label;
 
     /**
      * True if the link should be bolded.
      */
-    public boolean isBold = false;
+    public boolean isStrong = false;
 
     /**
      * True if we should include the type in the link label.  False otherwise.
@@ -69,9 +69,9 @@
 
     /**
-     * True if the link should be bolded.
+     * True if the link should be strong.
      */